<?php

namespace App\Controller;

use FOS\UserBundle\Controller\ResettingController as BaseController;
use FOS\UserBundle\Event\GetResponseUserEvent;
use FOS\UserBundle\Event\FormEvent;
use FOS\UserBundle\FOSUserEvents;
use FOS\UserBundle\Model\UserInterface;
use FOS\UserBundle\Model\UserManagerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\Routing\Annotation\Route;

class ResettingController extends BaseController
{
    /**
     * Override action from FOSUserBundle to prevent automatically enabeling a user
     *  if its account was created disabled by the admin
     * 
     * @Route("/resetting/reset/{token}", name="fos_user_resetting_reset")
     */
    public function resetAction(Request $request, $token)
    {
        $user = $this->get('fos_user.user_manager')->findUserByConfirmationToken($token);
        if (null === $user) {
            throw $this->createNotFoundException(sprintf('The user with password reset token "%s" does not exist', $token));
        }

        $event = new GetResponseUserEvent($user, $request);
        $this->get('event_dispatcher')->dispatch($event, FOSUserEvents::RESETTING_RESET_INITIALIZE);

        if (null !== $event->getResponse()) {
            return $event->getResponse();
        }

        $form = $this->$formFactory->createForm();
        $form->setData($user);

        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $event = new FormEvent($form, $request);
            $this->get('event_dispatcher')->dispatch($event, FOSUserEvents::RESETTING_RESET_SUCCESS);

            // Delete tokent but don't activate account
            $user->setConfirmationToken(null);
            $user->setPasswordRequestedAt(null);

            // Don't automatically enable user if it was created disabled
            // $user->setEnabled(true);

            $this->get('fos_user.user_manager')->updateUser($user);

            if (null === $response = $event->getResponse()) {
                $url = $this->generateUrl('fos_user_profile_show');
                $response = new RedirectResponse($url);
            }

            $this->get('event_dispatcher')->dispatch(new \Symfony\Component\EventDispatcher\GenericEvent($user), FOSUserEvents::RESETTING_RESET_COMPLETED);

            return $response;
        }

        return $this->render('@FOSUser/Resetting/reset.html.twig', [
            'token' => $token,
            'form' => $form->createView(),
        ]);
    }
}